Learn R Programming

rankFD (version 0.0.0.2)

Coal: Coal Acidity

Description

Coal acidity values determined under each of three NaOH concentration levels for two different samples from each type of coal

Usage

data(Coal)

Arguments

source

Hollander, M., Wolfe, D. A., Chicken, E. (2014) Nonparametric Statistical Methods. Wiley Series in Probability and Statistics.

Sternhell, S. (1958) Chemistry of brown coals VI: Further aspects of the chemistry of hydroxyl groups in Victorian brown coals. Australian Journal of Applied Science 9, 375--379.